# Changelog

## [1.0.0-alpha.0](https://github.com/DeadNews/galaxy-update/compare/v0.0.1...v1.0.0-alpha.0) - 2025-07-06

### 🚀 Features

- use `pyaml` for yaml dumping - ([46db9ab](https://github.com/DeadNews/galaxy-update/commit/46db9ab966a88f2cbf19bc89d2d38894272f7a1f))
- migrate from `poetry` to `uv` - ([6eb6854](https://github.com/DeadNews/galaxy-update/commit/6eb685446aaf363a3bf2f67b34c7be94975c2061))

### 🧹 Chores

- _(config)_ migrate config .renovaterc.json ([#14](https://github.com/deadnews/galaxy-update/issues/14)) - ([d47a7b8](https://github.com/DeadNews/galaxy-update/commit/d47a7b8b22b2381658a4398da1320654a6045aec))

### ⚙️ CI/CD

- _(github)_ add `python:3.13` to tests matrix ([#11](https://github.com/deadnews/galaxy-update/issues/11)) - ([caa6fd7](https://github.com/DeadNews/galaxy-update/commit/caa6fd7755c6e38b941a617aa20e532e16e152ed))

### ⬆️ Dependencies

- _(deps)_ update dependency click to v8.2.1 ([#37](https://github.com/deadnews/galaxy-update/issues/37)) - ([237814c](https://github.com/DeadNews/galaxy-update/commit/237814c6990bb99a96fdf4725f16906c128bbd4e))
- _(deps)_ update dependency click to v8.1.8 ([#24](https://github.com/deadnews/galaxy-update/issues/24)) - ([b98e7ce](https://github.com/DeadNews/galaxy-update/commit/b98e7ce2148e2549669f4b48037f151dd95d1644))
- _(deps)_ update dependency httpx to v0.28.1 ([#20](https://github.com/deadnews/galaxy-update/issues/20)) - ([2de5746](https://github.com/DeadNews/galaxy-update/commit/2de5746159fd030b036d3b0d9c5f21d3d3a6e258))
- _(deps)_ update dependency httpx to ^0.28.0 ([#19](https://github.com/deadnews/galaxy-update/issues/19)) - ([e44e708](https://github.com/DeadNews/galaxy-update/commit/e44e708610dfa076129013521bcd96911ace7a5b))

## [0.0.1](https://github.com/DeadNews/galaxy-update/commits/v0.0.1) - 2024-08-31

### 🚀 Features

- init ([#1](https://github.com/deadnews/galaxy-update/issues/1)) - ([811c0cc](https://github.com/DeadNews/galaxy-update/commit/811c0cc0adaeaed37ceda7f1d887bd877303c5d1))

<!-- generated by git-cliff -->
